@@ -977,7 +977,7 @@ gdk_dropfiles_filter (GdkXEvent *xev,
 
       event->dnd.x_root = pt.x;
       event->dnd.y_root = pt.y;
-      event->dnd.time = msg->time;
+      event->dnd.time = _gdk_win32_get_next_tick (msg->time);
 
       nfiles = DragQueryFile (hdrop, 0xFFFFFFFF, NULL, 0);
 
@@ -1336,7 +1336,10 @@ gdk_drag_find_window (GdkDragContext  *context,
     {
       *dest_window = gdk_win32_handle_table_lookup (GPOINTER_TO_UINT(recipient));
       if (*dest_window)
-	gdk_drawable_ref (*dest_window);
+	{
+	  *dest_window = gdk_window_get_toplevel (*dest_window);
+	  gdk_drawable_ref (*dest_window);
+	}
 
       if (context->source_window)
         *protocol = GDK_DRAG_PROTO_LOCAL;
